@@ -30,8 +30,10 @@ require 'aprs4r/AX25SocketConfiguration'
 
 require 'aprs4r/PluginConfiguration'
 require 'aprs4r/BeaconPluginConfiguration'
+require 'aprs4r/WeatherBeaconPluginConfiguration'
 require 'aprs4r/ProportionalBeaconPluginConfiguration'
 require 'aprs4r/GatewayPluginConfiguration'
+require 'aprs4r/BuddyGatewayPluginConfiguration'
 require 'aprs4r/DigipeaterPluginConfiguration'
 require 'aprs4r/LCD4LinuxPluginConfiguration'
 require 'aprs4r/XMLDataPluginConfiguration'
@@ -40,8 +42,10 @@ require 'aprs4r/MessagePluginConfiguration'
 require 'aprs4r/ISServerPluginConfiguration'
 require 'aprs4r/WeatherPluginConfiguration'
 require 'aprs4r/WMRWeatherPluginConfiguration'
+require 'aprs4r/DummyWeatherPluginConfiguration'
 require 'aprs4r/WS2300WeatherPluginConfiguration'
 require 'aprs4r/LogPluginConfiguration'
+require 'aprs4r/StatusPluginConfiguration'
 
 
 module APRS4R 
