@@ -18,23 +18,30 @@
 #
 
 
-class ConfigurationAttribute
-	
-  attr_reader :name, :mutable, :order, :type, :description, :length, :extension
-  
-  
-  def initialize( name, mutable, order, type, description, length, extension = nil)
-    
-    @name = name
-    @mutable = mutable
-    @order = order
-    @type = type
-    @description = description
-    @length = length
+module APRS4R
 
-    @extension = extension
+  class ConfigurationAttribute
+    
+    attr_reader :name, :type, :mutable, :length, :default, :description, :extension
+    
+    
+    def initialize( name, type, mutable, length, default, description, extension = nil)
+      
+      @name = name
+      @type = type
+      @mutable = mutable
+      @length = length
+      
+      @default = ""
+      @default = default if default
+
+      @description = description
+
+      @extension = extension
+      
+      return
+    end
     
-    return
   end
-  
+
 end
