@@ -403,7 +403,7 @@ module APRS4R
           end
 
           # read command byte
-          comand = value
+          command = value
 
           if (command & 0x0F) != 0 
             logger.warn( "Error: reading invalid command byte from tnc: #{command}")
