@@ -20,13 +20,17 @@
 require 'aprs4r/PluginConfiguration'
 
 
-class LogPluginConfiguration < PluginConfiguration
+module APRS4R
 
-  attr_reader :device, :file
-  attr_writer :device, :file
+  class LogPluginConfiguration < PluginConfiguration
+
+    attr_reader :device, :file
+    attr_writer :device, :file
+
+    def to_yaml_properties
+      return super + %w{@device @file}
+    end
 
-  def to_yaml_properties
-    return super + %w{@device @file}
   end
 
 end
