@@ -27,6 +27,8 @@ module APRS4R
 
     @@configuration = nil
 
+    @@plugins = nil
+
     @logger = APRS4RLogger.get_logger( "PluginManager")
 
 
@@ -34,6 +36,7 @@ module APRS4R
       logger.info( "init( configuration)")
       
       @@configuration = configuration.plugins
+      @@plugins = Array.new
 
       return
     end
@@ -63,10 +66,15 @@ module APRS4R
           plugin_class = "aprs4r" + "/" + type
 
           begin
+            logger.debug( "plugin_class: #{plugin_class}")
             require plugin_class
 
             plugin = eval( "#{type}.new( configuration)")
 
+            logger.debug( "plugin: #{plugin}")
+
+            add_plugin( plugin) if plugin
+
           rescue Exception  => ex
             logger.error( "Unable to load/initialize plugin #{plugin_class}: #{ex}")
           end
@@ -78,9 +86,33 @@ module APRS4R
         end
       }
 
+      logger.debug( "all plugins loaded")
+
       return
     end
 
+
+    def PluginManager.add_plugin( plugin)
+      logger.info( "add_plugin")
+      
+      @@plugins << plugin
+      
+      return
+    end
+    
+    
+    def PluginManager.get_plugin( type)
+      logger.info( "get_plugin")
+      
+      @@plugins.each{ |plugin|
+        return plugin if plugin.is_a?( type)
+      }
+      
+      return nil
+    end
+
+
   end
 
+
 end
