@@ -35,9 +35,11 @@ module APRS4R
 
     def attributes
 
+      online_url = "http://afu.friggleware.de/cgi-bin/trac.cgi/wiki/APRS4RConfigurationDevices#{@type}German"
+
       attributes = [ 
                     ConfigurationAttribute.new( "name",   "text",    true,  10, nil,   "Name"), 
-                    ConfigurationAttribute.new( "type",   "text",    false, 10, nil,   "Typ"), 
+                    ConfigurationAttribute.new( "type",   "text",    false, 10, nil,   "Typ", online_url), 
                     ConfigurationAttribute.new( "enable", "boolean", true,  10, false, "aktiviert")
                    ]
 
