@@ -29,6 +29,8 @@ module APRS4R
 
     @logger = APRS4RLogger.get_logger( "SocketSendThread");
 
+    @@QUEUE_MAX_LENGTH = 10
+
 
     def initialize( socket)
       logger.info( "initialize( socket)")
@@ -48,6 +50,13 @@ module APRS4R
 
       @queue.push( message)
 
+      if @queue.length > @@QUEUE_MAX_LENGTH
+        begin
+          @queue.pop( true)
+        rescue Exception 
+        end
+      end
+
       return
     end
 
@@ -67,7 +76,7 @@ module APRS4R
         message = @queue.pop
 
         if message 
-          logger.warn( "message send on #{@name}: #{message}")
+          logger.log( "message send on #{@name}: #{message}")
           # write message
           @socket.writeAPRSMessage( message)
         end
