@@ -47,75 +47,12 @@ module APRS4R
       @port.sync = true
       @port.flow_control = SerialPort::HARD
 
-      @wind_direction = nil
-      @wind_avg_speed = nil
-      @wind_gust_speed = nil
-      @rain_current = nil
-      @rain_total = nil
-      @rain_yesterday = nil
-      @temperature = nil
-      @humidity = nil
-      @dewpoint = nil
-      @pressure = nil
-
       Thread.new{ runWMRThread }
 
       return
     end
 
 
-    def createWeatherAPRSMessage
-      logger.info( "createWeatherAPRSMessage")
-
-      # copy default message
-      message = @message.clone
-
-      weather = String.new
-
-      # write wind data
-      wind_direction = "..."
-      wind_direction = sprintf( "%3.3i", @wind_direction) if @wind_direction
-
-      wind_avg_speed = "..."
-      wind_avg_speed = sprintf( "%3.3i", @wind_avg_speed) if @wind_avg_speed
-
-      wind_gust_speed = "g..."
-      wind_gust_speed = sprintf( "g%3.3i", @wind_gust_speed) if @wind_gust_speed
-
-      # temperature
-      temperature = "t..."
-      temperature = sprintf( "t%3.3i", @temperature) if @temperature
-
-      # rain
-      rain_current = "r..."
-      rain_current = sprintf( "r%3.3i", @rain_current) if @rain_current
-      
-      rain_yesterday = "p..."
-      rain_yesterday = sprintf( "p%3.3i", @rain_yesterday) if @rain_yesterday
-      
-      rain_total = "R..."
-      # rain_total = sprintf( "R%3.3i", @rain_total) if @rain_total
-
-      # humidity/pressure
-      humidity = "h.."
-      humidity = sprintf( "h%2.2i", @humidity) if @humidity
-
-      pressure = "b....."
-      pressure = sprintf( "b%5.5i", @pressure * 10) if @pressure
-
-      weather += wind_direction + "/" + wind_avg_speed + wind_gust_speed
-      weather += temperature + rain_current + rain_total + rain_yesterday
-      weather += humidity + pressure
-
-      logger.warn( "weather: #{weather}")
-
-      message.payload += weather
-
-      logger.warn( "message: #{message.to_s}")
-
-      return message
-    end
-
 
     def runWMRThread
       logger.info( "runWMRThread")
@@ -135,16 +72,16 @@ module APRS4R
 
       if record 
         if record.has_wind?
-          logger.info( "wind: direction: #{record.wind_direction}, avg: #{record.wind_avg_speed}, gust: #{record.wind_gust_speed}")
+          logger.info( "wind: direction: #{record.wind_direction}, avg: #{record.wind_avg}, gust: #{record.wind_gust}")
           @wind_direction = record.wind_direction
-          @wind_avg_speed = record.wind_avg_speed
-          @wind_gust_speed = record.wind_gust_speed
+          @wind_avg = record.wind_avg
+          @wind_gust = record.wind
         end
         
         if record.has_rain?
-          logger.info( "rain: current: #{record.rain_current}, total: #{record.rain_total}, yesterday: #{record.rain_yesterday}")
-          @rain_current = record.rain_current
-          @rain_total = record.rain_total
+          logger.info( "rain: 1h: #{record.rain_1h}, 24h: #{record.rain_24h}, yesterday: #{record.rain_yesterday}")
+          @rain_1h = record.rain_1h
+          @rain_total = record.rain_24h
           @rain_yesterday = record.rain_yesterday
         end
         
